==> haskell-prettyprinter-ansi-terminal-1.1.2-103-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prettyprinter-ansi-terminal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 prettyprinter-ansi-terminal
version:              1.1.2
visibility:           public
id:                   prettyprinter-ansi-terminal-1.1.2-1sthiGVyzuIJ7wPP72lyzA
key:                  prettyprinter-ansi-terminal-1.1.2-1sthiGVyzuIJ7wPP72lyzA
license:              BSD-2-Clause
maintainer:
    Simon Jakobi <simon.jakobi@gmail.com>, David Luposchainsky <dluposchainsky at google>

author:               David Luposchainsky
homepage:             http://github.com/quchen/prettyprinter
synopsis:             ANSI terminal backend for the »prettyprinter« package.
description:          See README.md
category:             User Interfaces, Text
abi:                  2feee5e993fe00042972cbb6c8075c06
exposed:              True
exposed-modules:
    Data.Text.Prettyprint.Doc.Render.Terminal
    Data.Text.Prettyprint.Doc.Render.Terminal.Internal
    Prettyprinter.Render.Terminal
    Prettyprinter.Render.Terminal.Internal

import-dirs:
    /usr/lib/ghc-8.10.4/site-local/prettyprinter-ansi-terminal-1.1.2

library-dirs:
    /usr/lib/ghc-8.10.4/site-local/prettyprinter-ansi-terminal-1.1.2

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.4/prettyprinter-ansi-terminal-1.1.2

hs-libraries:         HSprettyprinter-ansi-terminal-1.1.2-1sthiGVyzuIJ7wPP72lyzA
depends:
    ansi-terminal-0.11-Bapihu72YDSIMrY7HkFZ4n base-4.14.1.0
    prettyprinter-1.7.0-EaXozGZkeLW2KSLGdxKqQU text-1.2.4.1

haddock-interfaces:
    /usr/share/doc/haskell-prettyprinter-ansi-terminal/html/prettyprinter-ansi-terminal.haddock

haddock-html:         /usr/share/doc/haskell-prettyprinter-ansi-terminal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-prettyprinter-ansi-terminal-1.1.2-105-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prettyprinter-ansi-terminal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 prettyprinter-ansi-terminal
version:              1.1.2
visibility:           public
id:                   prettyprinter-ansi-terminal-1.1.2-Key1SSFz6eCKM9ni3T2IFJ
key:                  prettyprinter-ansi-terminal-1.1.2-Key1SSFz6eCKM9ni3T2IFJ
license:              BSD-2-Clause
maintainer:
    Simon Jakobi <simon.jakobi@gmail.com>, David Luposchainsky <dluposchainsky at google>

author:               David Luposchainsky
homepage:             http://github.com/quchen/prettyprinter
synopsis:             ANSI terminal backend for the »prettyprinter« package.
description:          See README.md
category:             User Interfaces, Text
abi:                  c391aa7a7009f6556954b39884900a36
exposed:              True
exposed-modules:
    Data.Text.Prettyprint.Doc.Render.Terminal
    Data.Text.Prettyprint.Doc.Render.Terminal.Internal
    Prettyprinter.Render.Terminal
    Prettyprinter.Render.Terminal.Internal

import-dirs:
    /usr/lib/ghc-8.10.5/site-local/prettyprinter-ansi-terminal-1.1.2

library-dirs:
    /usr/lib/ghc-8.10.5/site-local/prettyprinter-ansi-terminal-1.1.2

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.5/prettyprinter-ansi-terminal-1.1.2

hs-libraries:         HSprettyprinter-ansi-terminal-1.1.2-Key1SSFz6eCKM9ni3T2IFJ
depends:
    ansi-terminal-0.11-KZlfwqvn41oLlRmR1M9CEn base-4.14.2.0
    prettyprinter-1.7.0-2k3IpzNuta42oe8XIUM8Fs text-1.2.4.1

haddock-interfaces:
    /usr/share/doc/haskell-prettyprinter-ansi-terminal/html/prettyprinter-ansi-terminal.haddock

haddock-html:         /usr/share/doc/haskell-prettyprinter-ansi-terminal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
